#include <stdio.h>
#include <sys/types.h>
#include <sys/stat.h>
#include <fcntl.h>
#include <unistd.h>
#include <sys/ioctl.h>

#include "../include/inotify_lib.h"
#include "../include/error.h"


/*
 * Open an inotify fd
 */
int inotify_open(void)
{
	int fd_inotify;

	fd_inotify = open("/dev/inotify", O_RDONLY);
	
	return fd_inotify;
}

/*
 * Close an inotify fd
 */
void inotify_close(int fd_inotify)
{
	close(fd_inotify);
}

/*
 * Add an inotify watcher on the file 'filename'.
 * The field mask precise what events are to be caught.
 */
int inotify_add_watch(int fd_inotify, const char *filename, int mask)
{
	struct inotify_watch_request request;
	int file_fd;

	file_fd = open(filename, O_RDONLY);
	if (file_fd < 0) {
		return -EOPEN;
	}

	request.fd = file_fd;
	request.mask = mask;

	if (ioctl(fd_inotify, INOTIFY_WATCH, &request) < 0) {
		return -EIOCTL;
	}

	if (close(file_fd) < 0) {
		return -ECLOSE;
	}

	return SUCCESS;
}
